@@ -1,6 +1,5 @@
-/* Etherape
- * Copyright (C) 2000 Juan Toledo
- * $Id$
+/* EtherApe
+ * Copyright (C) 2000 Juan Toledo, Riccardo Ghetta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,15 +12,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 #include "appdata.h"
 #include "callbacks.h"
 #include "diagram.h"
