@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #if HAVE_CONFIG_H
@@ -65,7 +64,7 @@ static struct
   gboolean new;
   gint64 wait_ms;
   struct pcap_pkthdr lastpkt_hdr;
-  u_char lastpkt_data[MAXCAPSIZE];
+  unsigned char lastpkt_data[MAXCAPSIZE];
 } filecap_state;
 
 static capstatus_t capture_status = STOP;
@@ -331,7 +330,7 @@ static gboolean filecap_get_packet(gpointer unused)
 {
   int status;
   struct pcap_pkthdr *nextpkt_hdr;
-  const u_char *nextpkt_data;
+  const unsigned char *nextpkt_data;
   struct timeval pktdelta;
   size_t copylen;
 
