@@ -1,6 +1,5 @@
 /* EtherApe
- * Copyright (C) 2001 Juan Toledo
- * $Id$
+ * Copyright (C) 2001 Juan Toledo, Riccardo Ghetta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,15 +12,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 
 #include "appdata.h"
 #include "diagram.h"
@@ -964,7 +963,7 @@ canvas_node_update(node_id_t * node_id, canvas_node_t * canvas_node,
     {
       /* adds current to list of canvas nodes to delete */
       *delete_list = g_list_prepend( *delete_list, node_id);
-      g_my_debug ("Queing canvas node to remove.");
+      g_my_debug ("Queueing canvas node to remove.");
       need_reposition = TRUE;
       return FALSE;
     }
@@ -1500,7 +1499,7 @@ canvas_link_update(link_id_t * link_id, canvas_link_t * canvas_link,
   if (!link)
     {
       *delete_list = g_list_prepend( *delete_list, link_id);
-      g_my_debug ("Queing canvas link to remove.");
+      g_my_debug ("Queueing canvas link to remove.");
       return FALSE;
     }
 
