@@ -1,6 +1,5 @@
 /* EtherApe
- * Copyright (C) 2001 Juan Toledo
- * $Id$
+ * Copyright (C) 2001 Juan Toledo, Riccardo Ghetta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,6 +34,11 @@
 #include "stats/util.h"
 #include "node_windows.h"
 
+#if !defined(G_SOURCE_CONTINUE)
+// RHEL6/CENTOS6, SLE11 etc don't have this macro
+#define G_SOURCE_CONTINUE TRUE
+#endif
+
 typedef enum 
 {
   PROTO_COLUMN_COLOR = 0,
