@@ -1,6 +1,5 @@
 /* EtherApe
- * Copyright (C) 2001 Juan Toledo
- * $Id$
+ * Copyright (C) 2001 Juan Toledo, Riccardo Ghetta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -378,7 +376,7 @@ on_help_activate (GtkMenuItem * menuitem, gpointer user_data)
   GError *err = NULL;
 
 #if GTK_CHECK_VERSION(2, 13, 1)
-  gtk_show_uri (NULL, "ghelp:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
+  gtk_show_uri (NULL, "help:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
 #else
   gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
 #endif
